<?php

namespace App\Entity;

use App\Repository\FilmRepository;
use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;
use Doctrine\ORM\Mapping as ORM;

#[ORM\Entity(repositoryClass: FilmRepository::class)]
class Film
{
    #[ORM\Id]
    #[ORM\GeneratedValue]
    #[ORM\Column]
    private ?int $id = null;

    #[ORM\Column(length: 255)]
    private ?string $name = null;

    #[ORM\Column(length: 255, nullable: true)]
    private ?string $realisateur = null;

    #[ORM\Column(length: 255, nullable: true)]
    private ?string $genre = null;

    /**
     * @var Collection<int, CommonList>
     */
    #[ORM\OneToMany(targetEntity: CommonList::class, mappedBy: 'film', orphanRemoval: true)]
    private Collection $commonLists;

    /**
     * @var Collection<int, UserList>
     */
    #[ORM\ManyToMany(targetEntity: UserList::class, mappedBy: 'films')]
    private Collection $userLists;

    public function __construct()
    {
        $this->commonLists = new ArrayCollection();
        $this->userLists = new ArrayCollection();
    }

    public function getId(): ?int
    {
        return $this->id;
    }

    public function getName(): ?string
    {
        return $this->name;
    }

    public function setName(string $name): static
    {
        $this->name = $name;

        return $this;
    }

    public function getRealisateur(): ?string
    {
        return $this->realisateur;
    }

    public function setRealisateur(?string $realisateur): static
    {
        $this->realisateur = $realisateur;

        return $this;
    }

    public function getGenre(): ?string
    {
        return $this->genre;
    }

    public function setGenre(?string $genre): static
    {
        $this->genre = $genre;

        return $this;
    }

    /**
     * @return Collection<int, CommonList>
     */
    public function getCommonLists(): Collection
    {
        return $this->commonLists;
    }

    public function addCommonList(CommonList $commonList): static
    {
        if (!$this->commonLists->contains($commonList)) {
            $this->commonLists->add($commonList);
            $commonList->setFilm($this);
        }

        return $this;
    }

    public function removeCommonList(CommonList $commonList): static
    {
        if ($this->commonLists->removeElement($commonList)) {
            // set the owning side to null (unless already changed)
            if ($commonList->getFilm() === $this) {
                $commonList->setFilm(null);
            }
        }

        return $this;
    }

    /**
     * @return Collection<int, UserList>
     */
    public function getUserLists(): Collection
    {
        return $this->userLists;
    }

    public function addUserList(UserList $userList): static
    {
        if (!$this->userLists->contains($userList)) {
            $this->userLists->add($userList);
            $userList->addFilm($this);
        }

        return $this;
    }

    public function removeUserList(UserList $userList): static
    {
        if ($this->userLists->removeElement($userList)) {
            $userList->removeFilm($this);
        }

        return $this;
    }
}
